"use strict";
var program = require('commander');
var path = require('path');
var index_1 = require('../index');
var fs = require('mz/fs');
var theme_1 = require('../theme');
var file;
program
    .version(require('../../package.json').version)
    .description('Outputs a file or STDIN input with syntax highlighting')
    .option('-t, --theme <file>', 'Use a theme defined in a JSON file')
    .arguments('[file]')
    .action(function (f) { return file = f; })
    .parse(process.argv);
var codePromise;
if (!file && !process.stdin.isTTY) {
    // Input from STDIN
    process.stdin.setEncoding('utf8');
    var code_1 = '';
    process.stdin.on('readable', function () {
        var chunk = process.stdin.read();
        if (chunk !== null) {
            code_1 += chunk;
        }
    });
    codePromise = new Promise(function (resolve) {
        process.stdin.on('end', function () {
            resolve(code_1);
        });
    });
}
else {
    // Read file
    codePromise = fs.readFile(file, 'utf-8');
}
Promise.all([
    codePromise,
    program.theme ? fs.readFile(program.theme, 'utf8') : Promise.resolve()
]).then(function (_a) {
    var code = _a[0], theme = _a[1];
    var options = {
        ignoreIllegals: true,
        theme: theme && theme_1.parse(theme)
    };
    if (file) {
        var ext = path.extname(file).substr(1);
        if (ext && index_1.supportsLanguage(ext)) {
            options.language = ext;
        }
    }
    process.stdout.write(index_1.highlight(code, options));
}).then(function () {
    process.exit(0);
}).catch(function (err) {
    console.error(err);
    process.exit(1);
});
//# sourceMappingURL=highlight.js.map